@@ -1,7 +1,7 @@
 /* Clearlooks theme engine
  * Copyright (C) 2006 Richard Stellingwerff
  * Copyright (C) 2006 Daniel Borgman
- * Copyright (C) 2006 Benjamin Berg
+ * Copyright (C) 2007 Andrea Cimitan
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,10 +18,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Written by Benjamin Berg <benjamin@sipsolutions.net>
- * Based on code by Richard Stellingwerff <remenic@gmail.com>
- *              and Daniel Borgmann <daniel.borgmann@gmail.com>
- * from the ubuntulooks engine.
+ * Written by Andrea Cimitan <andrea.cimitan@gmail.com>
  */
 
 #include "clearlooks_draw.h"
@@ -33,46 +30,10 @@
 
 #include <cairo.h>
 
-static void
-clearlooks_inverted_draw_inset (cairo_t *cr, const ClearlooksColors *colors, int width, int height,
-                       double radius, uint8 corners)
-{
-	double top_x1 = 0, top_x2 = width, bot_x1 = 0, bot_x2 = width;
-	CairoColor hilight;
-	CairoColor shadow;
-
-	ge_shade_color (&colors->shade[8], 4, &hilight);
-	ge_shade_color (&colors->shade[8], 0.925, &shadow);
-
-	radius = MAX (1, ceil(radius));
-
-	if (corners & CR_CORNER_TOPLEFT)
-		top_x1 = radius-1;
-	
-	if (corners & CR_CORNER_TOPRIGHT)
-		top_x2 = width-radius+1;
-	
-	if (corners & CR_CORNER_BOTTOMLEFT)
-		bot_x1 = radius-1;
-	
-	if (corners & CR_CORNER_BOTTOMRIGHT)
-		bot_x2 = width-radius+1;
-	
-	cairo_set_line_width (cr, 1);
-	cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.05);
-	cairo_move_to (cr, top_x1, 0.0);
-	cairo_line_to (cr, top_x2, 0.0);
-	cairo_stroke (cr);
-	
-	cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, 0.5);
-	cairo_move_to (cr, bot_x1, height);
-	cairo_line_to (cr, bot_x2, height);
-	cairo_stroke (cr);
-}
 
 static void
 clearlooks_draw_top_left_highlight (cairo_t *cr,
-                 										const CairoColor *color,
+                 							const CairoColor *color,
                                     const WidgetParameters *params,
                                     int width, int height, gdouble radius)
 {
@@ -118,8 +79,8 @@ clearlooks_inverted_draw_button (cairo_t *cr,
 	double xoffset = 0, yoffset = 0;
 	double radius = params->radius;
 	const CairoColor *fill = &colors->bg[params->state_type];	
-	CairoColor border_normal;
 	const CairoColor *border_disabled = &colors->shade[4];
+	CairoColor border_normal;
 	CairoColor shadow;
 
 	ge_shade_color(&colors->shade[6], 1.05, &border_normal);
@@ -143,7 +104,7 @@ clearlooks_inverted_draw_button (cairo_t *cr,
 	if (params->xthickness == 3 || params->ythickness == 3)
 	{
 		cairo_translate (cr, 0.5, 0.5);
-		params->style_functions->draw_inset (cr, colors, width-1, height-1, radius, params->corners);
+		params->style_functions->draw_inset (cr, params->parentbg, 0, 0, width-1, height-1, radius+1, params->corners);
 		cairo_translate (cr, -0.5, -0.5);
 	}		
 	
@@ -406,7 +367,7 @@ clearlooks_inverted_draw_menuitem (cairo_t *cr,
                           const WidgetParameters          *widget,
                           int x, int y, int width, int height)
 {
-	CairoColor *fill = (CairoColor*)&colors->spot[1];
+	const CairoColor *fill = &colors->spot[1];
 	CairoColor fill_shade;
 	CairoColor border = colors->spot[2];
 	cairo_pattern_t *pattern;
@@ -465,11 +426,11 @@ clearlooks_inverted_draw_tab (cairo_t *cr,
                      const TabParameters    *tab,
                      int x, int y, int width, int height)
 {
-	CairoColor          *border1       = (CairoColor*)&colors->shade[6];
-	CairoColor          *border2       = (CairoColor*)&colors->shade[5];
-	CairoColor          *stripe_fill   = (CairoColor*)&colors->spot[1];
-	CairoColor          *stripe_border = (CairoColor*)&colors->spot[2];
-	CairoColor          *fill;
+	const CairoColor    *border1       = &colors->shade[6];
+	const CairoColor    *border2       = &colors->shade[5];
+	const CairoColor    *stripe_fill   = &colors->spot[1];
+	const CairoColor    *stripe_border = &colors->spot[2];
+	const CairoColor    *fill;
 	CairoColor           hilight;
 	CairoColor           shadow;
 
@@ -510,7 +471,7 @@ clearlooks_inverted_draw_tab (cairo_t *cr,
 	}
 	
 	/* Set the fill color */
-	fill = (CairoColor*)&colors->bg[params->state_type];
+	fill = &colors->bg[params->state_type];
 
 	/* Set tab shape */
 	ge_cairo_rounded_rectangle (cr, 0, 0, width-1, height-1,
@@ -535,7 +496,6 @@ clearlooks_inverted_draw_tab (cairo_t *cr,
 		                                     height, radius);*/
 	}
 	
-
 	if (params->active)
 	{
 		pattern = cairo_pattern_create_linear ( tab->gap_side == CL_GAP_LEFT   ? width-1  : 0,
@@ -731,7 +691,7 @@ clearlooks_inverted_draw_list_view_header (cairo_t *cr,
                                   int x, int y, int width, int height)
 {
 	const CairoColor *fill = &colors->bg[params->state_type];
-	CairoColor      *border = (CairoColor*)&colors->shade[4];
+	const CairoColor *border = &colors->shade[4];
 	cairo_pattern_t *pattern;
 	CairoColor hilight_header;
 	CairoColor hilight;
@@ -755,7 +715,7 @@ clearlooks_inverted_draw_list_view_header (cairo_t *cr,
 	
 	cairo_line_to (cr, width, 0.5);
 	
-	cairo_set_source_rgb (cr, hilight.r, hilight.g, hilight.b);
+	ge_cairo_set_color (cr, &hilight);
 	cairo_stroke (cr);
 	
 	/* Draw bottom border */
@@ -782,10 +742,10 @@ clearlooks_inverted_draw_list_view_header (cairo_t *cr,
 		separator.horizontal = FALSE;
 		
 		if (params->ltr)
-			params->style_functions->draw_separator (cr, colors, params, &separator,
+			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
 			                                         width-1.5, 4.0, 2, height-8.0);
 		else
-			params->style_functions->draw_separator (cr, colors, params, &separator,
+			params->style_functions->draw_separator (cr, &colors->shade[3], params, &separator,
 			                                         1.5, 4.0, 2, height-8.0);
 	}
 }
@@ -801,7 +761,7 @@ clearlooks_inverted_draw_scrollbar_stepper (cairo_t *cr,
 {
 	CairoCorners corners = CR_CORNER_NONE;
 	CairoColor border;
-	CairoColor  s1, s2, s3;
+	CairoColor s1, s2, s3;
 	cairo_pattern_t *pattern;
 	ShadowParameters shadow;
 	double radius = MIN (widget->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
@@ -893,7 +853,7 @@ clearlooks_inverted_draw_scrollbar_slider (cairo_t *cr,
 
 	if (scrollbar->has_color)
 	{
-		CairoColor *border  = (CairoColor*)&colors->shade[8];
+		const CairoColor *border = &colors->shade[8];
 		CairoColor  fill    = scrollbar->color;
 		CairoColor  hilight;
 		CairoColor  shade1, shade2, shade3;
@@ -932,8 +892,8 @@ clearlooks_inverted_draw_scrollbar_slider (cairo_t *cr,
 		cairo_pattern_t *pattern;
 		int bar_x, i;
 		
-		CairoColor *dark  = (CairoColor*)&colors->shade[4];
-		CairoColor *light = (CairoColor*)&colors->shade[0];		
+		const CairoColor *dark  = &colors->shade[4];
+		const CairoColor *light = &colors->shade[0];		
 
 		ge_shade_color(&colors->shade[6], 1.05, &border);
 
@@ -1029,17 +989,16 @@ clearlooks_inverted_draw_selected_cell (cairo_t                  *cr,
 void
 clearlooks_register_style_inverted (ClearlooksStyleFunctions *functions)
 {
-	functions->draw_inset							= clearlooks_inverted_draw_inset;
-	functions->draw_button        		= clearlooks_inverted_draw_button;
-	functions->draw_slider     				= clearlooks_inverted_draw_slider;
+	functions->draw_button            = clearlooks_inverted_draw_button;
+	functions->draw_slider            = clearlooks_inverted_draw_slider;
 	functions->draw_slider_button     = clearlooks_inverted_draw_slider_button;
 	functions->draw_progressbar_fill  = clearlooks_inverted_draw_progressbar_fill;
-	functions->draw_menuitem				  = clearlooks_inverted_draw_menuitem;
-	functions->draw_menubaritem				= clearlooks_inverted_draw_menubaritem;
-	functions->draw_tab								= clearlooks_inverted_draw_tab;
-	functions->draw_list_view_header	= clearlooks_inverted_draw_list_view_header;
+	functions->draw_menuitem          = clearlooks_inverted_draw_menuitem;
+	functions->draw_menubaritem       = clearlooks_inverted_draw_menubaritem;
+	functions->draw_tab               = clearlooks_inverted_draw_tab;
+	functions->draw_list_view_header  = clearlooks_inverted_draw_list_view_header;
 	functions->draw_scrollbar_stepper = clearlooks_inverted_draw_scrollbar_stepper;	
 	functions->draw_scrollbar_slider  = clearlooks_inverted_draw_scrollbar_slider;
-	functions->draw_selected_cell			= clearlooks_inverted_draw_selected_cell;
+	functions->draw_selected_cell     = clearlooks_inverted_draw_selected_cell;
 }
 
